@@ -12,8 +12,8 @@ include("../application.inc.php");
 require_login();
 require_priv("admin");
 
-$DOC_TITLE = $Brands_Management;
-include("templates/header.ihtml");
+$DOC_TITLE = "Brands_Management";
+include("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -42,9 +42,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "insert";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Add_Brand;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/brand_form.ihtml");
+			$frm["submit_caption"] = "Add_Brand";
+			include("$CFG->dirroot"."/form_header.php");
+			load_brand_form_template($frm, $id, $errors);
 		}
 		break;
 
@@ -62,9 +62,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "update";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Save_Changes;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/brand_form.ihtml");
+			$frm["submit_caption"] = "Save_Changes";
+			include("$CFG->dirroot"."/form_header.php");
+			load_brand_form_template($frm, $id, $errors);
 		}
 		break;
 
@@ -86,26 +86,49 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("templates/footer.ihtml");
+include("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function load_brand_form_template($frm, $id, $errors) {
+
+	global $CFG, $ME;
+	global $SESSION;
+//	include ($CFG->globalerror);
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/brand_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"		=> $frm["newmode"],
+			"brand_id"		=> $id,
+			"frm_name"		=> ov($frm["name"]),
+			"errors_name"		=> errmsg($errors->brand_name),
+			"frm_description"	=> ov($frm["description"]),
+			"errors_description"	=> errmsg($errors->brand_description),
+			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/brand_form.ihtml");
+}
+
 function print_add_brand_form() {
 /* print a blank brand form so we can add a new brand */
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
 	$frm["newmode"] = "insert";
 	$frm["name"] = "";
 	$frm["description"] = "";
-	$frm["submit_caption"] = $Add_Brand;
-
-	include("templates/brand_form.ihtml");
+	$frm["submit_caption"] = "Add_Brand";
+	load_brand_form_template($frm, $id, $errors);
 }
 
 function print_edit_brand_form($id) {
@@ -113,7 +136,7 @@ function print_edit_brand_form($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the brand */
 	$qid = db_query("
@@ -125,9 +148,8 @@ function print_edit_brand_form($id) {
 
 	/* set values for the form */
 	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
-
-	include("templates/brand_form.ihtml");
+	$frm["submit_caption"] = "Save_Changes";
+	load_brand_form_template($frm, $id, $errors);
 }
 
 function delete_brand($id) {
@@ -136,7 +158,7 @@ function delete_brand($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$qid = db_begin();
 
@@ -160,7 +182,21 @@ function delete_brand($id) {
 
 	$qid = db_commit();
 
-	include("templates/brand_deleted.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/brand_deleted.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/brand_deleted.ihtml");
 }
 
 function insert_brand($frm) {
@@ -169,7 +205,7 @@ function insert_brand($frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -179,7 +215,20 @@ function insert_brand($frm) {
 	VALUES ('$frm[name]', '$frm[description]')
 	");
 
-	include("templates/brand_added.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/brand_added.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/brand_added.ihtml");
 }
 
 function update_brand($id, $frm) {
@@ -188,7 +237,7 @@ function update_brand($id, $frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -200,7 +249,21 @@ function update_brand($id, $frm) {
 	WHERE id = '$id'
 	");
 
-	include("templates/brand_updated.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/brand_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"http_post_vars_name"	=> ov($frm[name]),
+			"backurl"		=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/brand_updated.ihtml");
 }
 
 function print_brands_list() {
@@ -210,7 +273,7 @@ function print_brands_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
@@ -241,25 +304,61 @@ function print_brands_list() {
 		$last = $SESSION["numr"] - 1;
 	}
 
-	include("templates/brand_list.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/brand_list.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
+	$t->set_var("pages_links_top_blck", "");
+	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
+	$t->set_var("pages_links_bottom_blck", "");
+	if ($num_pages > 1) {
+		require("pages_links.php");
+		$t->set_var("pages_links", $pages_links);
+		$t->parse("pages_links_top_blck", "pages_links_top", true);
+		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
+	}
+	$t->set_block("page", "brand_row", "brand_rows");
+	$t->set_var("brand_rows", "");
+	for ($i=$first; $i<=$last; $i++) {
+		$t->set_var(array(
+				"session_brands_name"		=> ov($SESSION["brands"][$i]["name"]),
+				"session_brands_id"		=> $SESSION["brands"][$i]["id"],
+				"session_brands_description"	=> ovwbr($SESSION["brands"][$i]["description"])
+		));
+		$t->parse("brand_rows", "brand_row", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/brand_list.ihtml");
 }
 
 function print_import_brands_form() {
 /* print the import brand form so we can add/update brands from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Button_Label;
+	$frm["submit_caption"] = "Import_Button_Label";
 	$frm["newmode"] = "update_imp";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_brands($userfile) {
 /* Import brands from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 	$errors = new Object;
 
 	$qid = db_begin();
@@ -277,7 +376,7 @@ function import_brands($userfile) {
 
 		/* ... and let's see if the brand already exists ... */
 		$qid = db_query("
-		SELECT id FROM brands WHERE name = '$fldarr[0]'
+		SELECT id, name FROM brands WHERE name = '$fldarr[0]'
 		");
 		if (db_num_rows($qid) == 0) {
 			/* ... if it doesn't exist let's create it ... */
@@ -303,7 +402,18 @@ function import_brands($userfile) {
 	$qid = db_commit();
 	
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
