@@ -23,8 +23,8 @@ include("../application.inc.php");
 require_login();
 require_priv("admin");
 
-$DOC_TITLE = $Categories_Management;
-include("templates/header.ihtml");
+$DOC_TITLE = "Categories_Management";
+include("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -72,11 +72,11 @@ switch (nvl($mode)) {
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Add_Subcategory;
+			$frm["submit_caption"] = "Add_Subcategory";
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree(&$category_options, $frm["parent"]);
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/category_form.ihtml");
+			build_category_tree($category_options, $frm["parent"]);
+			include("$CFG->dirroot"."/form_header.php");
+			load_category_form_template($frm, $id, $category_options, $errors);
 		}
 		break;
 
@@ -103,11 +103,11 @@ switch (nvl($mode)) {
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Save_Changes;
+			$frm["submit_caption"] = "Save_Changes";
 			/* build the categories listbox options, preselect the selected item */
-			build_category_tree(&$category_options, $frm["parent"]);
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/category_form.ihtml");
+			build_category_tree($category_options, $frm["parent"]);
+			include("$CFG->dirroot"."/form_header.php");
+			load_category_form_template($frm, $id, $category_options, $errors);
 		}
 		break;
 
@@ -129,18 +129,45 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("templates/footer.ihtml");
+include("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function load_category_form_template($frm, $id, $category_options, $errors) {
+
+	global $CFG, $ME;
+	global $SESSION;
+//	include ($CFG->globalerror);
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/category_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"		=> $frm["newmode"],
+			"category_id"		=> $id,
+			"category_options"	=> $category_options,
+			"frm_name"		=> ov($frm["name"]),
+			"errors_name"		=> errmsg($errors->category_name),
+			"frm_special_level"	=> $frm["special_level"],
+			"errors_special_level"	=> errmsg($errors->special_level),
+			"frm_description"	=> ov($frm["description"]),
+			"errors_description"	=> errmsg($errors->category_description),
+			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/category_form.ihtml");
+}
+
 function print_add_category_form($id) {
 /* print a blank category form so we can add a new category */
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
 	$frm["parent"] = array($id);
@@ -148,12 +175,12 @@ function print_add_category_form($id) {
 	$frm["name"] = "";
 	$frm["special_level"] = "";
 	$frm["description"] = "";
-	$frm["submit_caption"] = $Add_Subcategory;
+	$frm["submit_caption"] = "Add_Subcategory";
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree(&$category_options, $frm["parent"]);
+	build_category_tree($category_options, $frm["parent"]);
 
-	include("templates/category_form.ihtml");
+	load_category_form_template($frm, $id, $category_options, $errors);
 }
 
 function print_edit_category_form($id) {
@@ -161,7 +188,7 @@ function print_edit_category_form($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the category */
 	$qid = db_query("
@@ -174,12 +201,12 @@ function print_edit_category_form($id) {
 	/* set values for the form */
 	$frm["parent"] = array($frm["parent_id"]);
 	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
+	$frm["submit_caption"] = "Save_Changes";
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree(&$category_options, $frm["parent"]);
+	build_category_tree($category_options, $frm["parent"]);
 
-	include("templates/category_form.ihtml");
+	load_category_form_template($frm, $id, $category_options, $errors);
 }
 
 function delete_category($id) {
@@ -189,7 +216,7 @@ function delete_category($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$qid = db_begin();
 
@@ -261,7 +288,22 @@ function delete_category($id) {
 
 	$qid = db_commit();
 
-	include("templates/category_deleted.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/category_deleted.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"cat_name"	=> ov($cat->name),
+			"cat_parent"	=> ov($cat->parent),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/category_deleted.ihtml");
 }
 
 function insert_subcategory($id, $frm) {
@@ -270,7 +312,7 @@ function insert_subcategory($id, $frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -280,7 +322,20 @@ function insert_subcategory($id, $frm) {
 	VALUES ('$frm[parent]', '$frm[name]', '$frm[special_level]', '$frm[description]')
 	");
 
-	include("templates/category_added.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/category_added.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/category_added.ihtml");
 }
 
 function update_category($id, $frm) {
@@ -289,7 +344,7 @@ function update_category($id, $frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -303,7 +358,21 @@ function update_category($id, $frm) {
 	WHERE id = '$id'
 	");
 
-	include("templates/category_updated.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/category_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/category_updated.ihtml");
 }
 
 function print_category_list() {
@@ -313,7 +382,7 @@ function print_category_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
@@ -343,25 +412,63 @@ function print_category_list() {
 		$last = $SESSION["numr"] - 1;
 	}
 
-	include("templates/category_list.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/category_list.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
+	$t->set_var("pages_links_top_blck", "");
+	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
+	$t->set_var("pages_links_bottom_blck", "");
+	if ($num_pages > 1) {
+		require("pages_links.php");
+		$t->set_var("pages_links", $pages_links);
+		$t->parse("pages_links_top_blck", "pages_links_top", true);
+		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
+	}
+	$t->set_block("page", "category_row", "category_rows");
+	$t->set_var("category_rows", "");
+	for ($i=$first; $i<=$last; $i++) {
+		$t->set_var(array(
+				"session_categories_name"		=> ov($SESSION["categories"][$i]["name"]),
+				"session_categories_id"			=> $SESSION["categories"][$i]["id"],
+				"session_categories_special_level"	=> $SESSION["categories"][$i]["special_level"],
+				"session_categories_parent"		=> ov($SESSION["categories"][$i]["parent"]),
+				"session_categories_description"	=> ovwbr($SESSION["categories"][$i]["description"])
+		));
+		$t->parse("category_rows", "category_row", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/category_list.ihtml");
 }
 
 function print_import_category_form() {
 /* print the import category form so we can add/update categories from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Button_Label;
+	$frm["submit_caption"] = "Import_Button_Label";
 	$frm["newmode"] = "update_imp";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_category($userfile) {
 /* Import categories from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 	$errors = new Object;
 
 //	/* Let's open a transaction */
@@ -424,7 +531,18 @@ function import_category($userfile) {
 	$qid = db_commit();
 	
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
