@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -24,6 +24,16 @@ require_priv("admin");
 
 $SESSION["goback"]["request_uri"] = $REQUEST_URI;
 $SESSION["goback"]["query_string"] = $QUERY_STRING;
-include("templates/".$SESSION["lang"]."/index.ihtml");
-include("templates/footer.ihtml");
+
+$DOC_TITLE = "Administration";
+include ("header.php");
+
+$t = new Template();
+$t->set_file(array("page" => "templates/".$SESSION["lang"]."/index.ihtml"));
+$t->set_var("cfg_myname", $CFG->myname);
+$t->pparse("out", "page");
+//include("templates/".$SESSION["lang"]."/index.ihtml");
+
+include("footer.php");
+
 ?>
