@@ -12,8 +12,8 @@ include("../application.inc.php");
 require_login();
 require_priv("admin");
 
-$DOC_TITLE = $Orders_States_Management;
-include("templates/header.ihtml");
+$DOC_TITLE = "Orders_States_Management";
+include("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -42,9 +42,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "insert";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Add_Order_State;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/order_state_form.ihtml");
+			$frm["submit_caption"] = "Add_Order_State";
+			include("$CFG->dirroot"."/form_header.php");
+			load_order_state_form_template($frm, $id, $errors);
 		}
 		break;
 
@@ -62,9 +62,9 @@ switch (nvl($mode)) {
 			$frm["newmode"] = "update";
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
-			$frm["submit_caption"] = $Save_Changes;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/order_state_form.ihtml");
+			$frm["submit_caption"] = "Save_Changes";
+			include("$CFG->dirroot"."/form_header.php");
+			load_order_state_form_template($frm, $id, $errors);
 		}
 		break;
 
@@ -86,26 +86,50 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("templates/footer.ihtml");
+include("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function load_order_state_form_template($frm, $id, $errors) {
+
+	global $CFG, $ME;
+	global $SESSION;
+//	include ($CFG->globalerror);
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/order_state_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"		=> $frm["newmode"],
+			"order_id"		=> $id,
+			"frm_name"		=> ov($frm["name"]),
+			"errors_name"		=> errmsg($errors->order_state_name),
+			"frm_description"	=> ov($frm["description"]),
+			"errors_description"	=> errmsg($errors->order_state_description),
+			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/order_state_form.ihtml");
+}
+
 function print_add_order_state_form() {
 /* print a blank order state form so we can add a new order state */
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
 	$frm["newmode"] = "insert";
 	$frm["name"] = "";
 	$frm["description"] = "";
-	$frm["submit_caption"] = $Add_Order_State;
+	$frm["submit_caption"] = "Add_Order_State";
 
-	include("templates/order_state_form.ihtml");
+	load_order_state_form_template($frm, $id, $errors);
 }
 
 function print_edit_order_state_form($id) {
@@ -113,7 +137,7 @@ function print_edit_order_state_form($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the order state */
 	$qid = db_query("
@@ -125,9 +149,9 @@ function print_edit_order_state_form($id) {
 
 	/* set values for the form */
 	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
+	$frm["submit_caption"] = "Save_Changes";
 
-	include("templates/order_state_form.ihtml");
+	load_order_state_form_template($frm, $id, $errors);
 }
 
 function delete_order_state($id) {
@@ -136,7 +160,7 @@ function delete_order_state($id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if ($id > 0) {
 		$qid = db_begin();
@@ -164,7 +188,21 @@ function delete_order_state($id) {
 
 		$qid = db_commit();
 
-		include("templates/order_state_deleted.ihtml");
+		if (empty($SESSION["goback"]["query_string"]))
+			$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+		else
+			$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+		$t = new Template();
+		$t->set_file(array("page" => "templates/order_state_deleted.ihtml"));
+		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		$t->set_var(array(
+				"frm_name"	=> ov($frm[name]),
+				"backurl"	=> $backurl
+		));
+		$t->pparse("out", "page");
+//		include("templates/order_state_deleted.ihtml");
 	} else print_orders_states_list();
 }
 
@@ -174,7 +212,7 @@ function insert_order_state($frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -184,7 +222,21 @@ function insert_order_state($frm) {
 	VALUES ('$frm[name]', '$frm[description]')
 	");
 
-	include("templates/order_state_added.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/order_state_added.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/order_state_added.ihtml");
 }
 
 function update_order_state($id, $frm) {
@@ -193,7 +245,7 @@ function update_order_state($id, $frm) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	while (list($key, $val) = each($frm)){
 		if (is_string($val)) $frm[$key] = addslashes($val);
@@ -205,7 +257,21 @@ function update_order_state($id, $frm) {
 	WHERE id = '$id'
 	");
 
-	include("templates/order_state_updated.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/order_state_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_name"	=> ov($frm[name]),
+			"backurl"	=> $backurl
+	));
+	$t->pparse("out", "page");
+//	include("templates/order_state_updated.ihtml");
 }
 
 function print_orders_states_list() {
@@ -215,7 +281,7 @@ function print_orders_states_list() {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
@@ -246,25 +312,61 @@ function print_orders_states_list() {
 		$last = $SESSION["numr"] - 1;
 	}
 
-	include("templates/orders_states_list.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/order_state_list.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
+	$t->set_var("pages_links_top_blck", "");
+	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
+	$t->set_var("pages_links_bottom_blck", "");
+	if ($num_pages > 1) {
+		require("pages_links.php");
+		$t->set_var("pages_links", $pages_links);
+		$t->parse("pages_links_top_blck", "pages_links_top", true);
+		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
+	}
+	$t->set_block("page", "order_state_row", "order_state_rows");
+	$t->set_var("order_state_rows", "");
+	for ($i=$first; $i<=$last; $i++) {
+		$t->set_var(array(
+				"session_order_state_name"		=> ov($SESSION["order_state"][$i]["name"]),
+				"session_order_state_id"		=> ov($SESSION["order_state"][$i]["id"]),
+				"session_order_state_description"	=> ovwbr($SESSION["order_state"][$i]["description"])
+		));
+		$t->parse("order_state_rows", "order_state_row", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/order_state_list.ihtml");
 }
 
 function print_import_orders_states_form() {
 /* print the import order states form so we can add/update order states from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Button_Label;
+	$frm["submit_caption"] = "Import_Button_Label";
 	$frm["newmode"] = "update_imp";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_orders_states($userfile) {
 /* Import order states from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 	$errors = new Object;
 
 	$qid = db_begin();
@@ -282,7 +384,7 @@ function import_orders_states($userfile) {
 
 		/* ... and let's see if the state already exists ... */
 		$qid = db_query("
-		SELECT id FROM orders_states WHERE name = '$fldarr[0]'
+		SELECT id, name FROM orders_states WHERE name = '$fldarr[0]'
 		");
 		if (db_num_rows($qid) == 0) {
 			/* ... if it doesn't exist let's create it ... */
@@ -307,7 +409,18 @@ function import_orders_states($userfile) {
 	$qid = db_commit();
 
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
