@@ -23,8 +23,8 @@ include("../application.inc.php");
 require_login();
 require_priv("admin");
 
-$DOC_TITLE = $Products_Management;
-include("templates/header.ihtml");
+$DOC_TITLE = "Products_Management";
+include("header.php");
 
 switch (nvl($mode)) {
 	case "add" :
@@ -95,11 +95,11 @@ switch (nvl($mode)) {
 			$frm["special_level"] = $HTTP_POST_VARS["special_level"];
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
-			$frm["submit_caption"] = $Add_Product;
+			$frm["submit_caption"] = "Add_Product";
 			/* build the categories listbox options, preselect the top item */
-			build_category_tree(&$category_options, $frm["categories"]);
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/product_form.ihtml");
+			build_category_tree($category_options, $frm["categories"]);
+			include("$CFG->dirroot"."/form_header.php");
+			load_product_form_template($frm, $category_options, $errors);
 		}
 		break;
 
@@ -110,12 +110,12 @@ switch (nvl($mode)) {
 		if ($HTTP_POST_VARS["old_product_id"] != $HTTP_POST_VARS["product_id"]) {
 			product_id_exists($HTTP_POST_VARS["product_id"], &$errors, &$errormsg);
 		}
-		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_product_name($HTTP_POST_VARS["name"], &$errors, &$errormsg);
 		validate_price($HTTP_POST_VARS["price"], &$errors, &$errormsg);
 		validate_discount($HTTP_POST_VARS["discount"], $HTTP_POST_VARS["discqty"], &$errors, &$errormsg);
 		if($SESSION["weight_used"])
 			validate_weight($HTTP_POST_VARS["weight"], &$errors, &$errormsg);
+		validate_special_level($HTTP_POST_VARS["special_level"], &$errors, &$errormsg);
 		validate_product_description($HTTP_POST_VARS["description"], &$errors, &$errormsg);
 		validate_product_extended_description($HTTP_POST_VARS["extended_description"], &$errors, &$errormsg);
 		if (empty($errormsg)) {
@@ -162,11 +162,11 @@ switch (nvl($mode)) {
 			$frm["description"] = $HTTP_POST_VARS["description"];
 			$frm["extended_description"] = $HTTP_POST_VARS["extended_description"];
 			$frm["delete_image"] = $HTTP_POST_VARS["delete_image"];
-			$frm["submit_caption"] = $Save_Changes;
+			$frm["submit_caption"] = "Save_Changes";
 			/* build the categories listbox options, preselect the top item */
-			build_category_tree(&$category_options, $frm["categories"]);
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/product_form.ihtml");
+			build_category_tree($category_options, $frm["categories"]);
+			include("$CFG->dirroot"."/form_header.php");
+			load_product_form_template($frm, $category_options, $errors);
 		}
 		break;
 
@@ -203,19 +203,109 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("templates/footer.ihtml");
+include("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function load_product_form_template($frm, $category_options, $errors) {
+
+	global $CFG, $ME;
+	global $SESSION;
+	global $weightunity;
+//	include ($CFG->globalerror);
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"frm_old_product_id"		=> ov($frm["old_product_id"]),
+			"frm_old_imagetype"		=> $frm["old_imagetype"],
+			"frm_old_imagewidth"		=> $frm["old_imagewidth"],
+			"frm_old_imageheight"		=> $frm["old_imageheight"],
+			"frm_old_thumbwidth"		=> $frm["old_thumbwidth"],
+			"frm_old_thumbheight"		=> $frm["old_thumbheight"],
+			"session_max_file_size_images"	=> $SESSION["max_file_size_images"],
+			"category_options"		=> $category_options,
+			"frm_product_id"		=> ov($frm["product_id"]),
+			"errors_product_id"		=> errmsg($errors->product_id),
+			"frm_product_name"		=> ov($frm["name"]),
+			"errors_product_name"		=> errmsg($errors->product_name),
+			"frm_product_price"		=> $frm["price"],
+			"errors_product_price"		=> errmsg($errors->price),
+			"frm_product_discount"		=> $frm["discount"],
+			"errors_product_discount"	=> errmsg($errors->discount),
+			"frm_product_discqty"		=> $frm["discqty"],
+			"errors_product_discqty"	=> errmsg($errors->discqty),
+			"frm_special_flag"		=> $frm["special_flag"] ? "checked" : "",
+			"frm_product_special_level"	=> $frm["special_level"],
+			"errors_product_special_level"	=> errmsg($errors->special_level),
+			"frm_product_description"	=> ov($frm["description"]),
+			"errors_product_description"	=> errmsg($errors->description),
+			"frm_product_extended_description"	=> ov($frm["extended_description"]),
+			"errors_product_extended_description"	=> errmsg($errors->extended_description),
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->set_block("page", "brand_used", "brand_used_blck");
+	$t->set_var("brand_used_blck", "");
+	if($SESSION["brand_used"]) {
+		$t->set_block("brand_used", "brand_used_option", "brand_used_options");
+		$t->set_var("brand_used_options", "");
+		for ($i=0; $i<$frm["numbrands"]; $i++) {
+			$t->set_var(array(
+					"frm_brand_id"		=> $frm["brand"][$i]["id"],
+					"frm_brand_selected"	=> $frm["brand_id"] == $frm["brand"][$i]["id"] ? "selected" : "",
+					"frm_brand_name"	=> $frm["brand"][$i]["name"]
+			));
+			$t->parse("brand_used_options", "brand_used_option", true);
+		}
+		$t->parse("brand_used_blck", "brand_used", true);
+	}
+	$t->set_block("page", "iva_used", "iva_used_blck");
+	$t->set_var("iva_used_blck", "");
+	if($SESSION["iva_used"]) {
+		$t->set_block("iva_used", "iva_used_option", "iva_used_options");
+		$t->set_var("iva_used_options", "");
+		for ($i=0; $i<$frm["numivavalues"]; $i++) {
+			$t->set_var(array(
+					"frm_iva_id"		=> $frm["iva"][$i]["id"],
+					"frm_iva_selected"	=> $frm["iva_id"] == $frm["iva"][$i]["id"] ? "selected" : "",
+					"frm_iva_iva"		=> $frm["iva"][$i]["iva"]
+			));
+			$t->parse("iva_used_options", "iva_used_option", true);
+		}
+		$t->parse("iva_used_blck", "iva_used", true);
+	}
+	$t->set_block("page", "weight_used", "weight_used_blck");
+	$t->set_var("weight_used_blck", "");
+	if($SESSION["weight_used"]) {
+		$t->set_var(array(
+				"frm_product_weight"	=> $frm["weight"],
+				"errors_product_weight"	=> errmsg($errors->weight),
+		));
+		$t->parse("weight_used_blck", "weight_used", true);
+	}
+	$t->set_block("page", "delete_actual_image", "delete_actual_image_blck");
+	$t->set_var("delete_actual_image_blck", "");
+	if ($frm["newmode"] == "update" && $frm["old_imagetype"] != "") {
+		$t->set_var("frm_delete_image_checked", $frm["delete_image"] ? "checked" : "");
+		$t->parse("delete_actual_image_blck", "delete_actual_image", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/product_form.ihtml");
+}
+
 function print_add_product_form($category_id = 1) {
 /* print a blank product form so we can add a new product */
 
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
 	$frm["categories"] = array($category_id);
@@ -231,7 +321,7 @@ function print_add_product_form($category_id = 1) {
 	$frm["special_level"] = "";
 	$frm["description"] = "";
 	$frm["extended_description"] = "";
-	$frm["submit_caption"] = $Add_Product;
+	$frm["submit_caption"] = "Add_Product";
 
 	if ($SESSION["brand_used"]) {
 		// load up all the brands
@@ -260,9 +350,8 @@ function print_add_product_form($category_id = 1) {
 	}
 
 	/* build the categories listbox options, preselect the top item */
-	build_category_tree(&$category_options, $frm["categories"]);
-
-	include("templates/product_form.ihtml");
+	build_category_tree($category_options, $frm["categories"]);
+	load_product_form_template($frm, $category_options, $errors);
 }
 
 function print_edit_product_form($product_id) {
@@ -271,7 +360,7 @@ function print_edit_product_form($product_id) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the product */
 	$qid = db_query("SELECT * FROM products WHERE id = '$product_id'");
@@ -326,12 +415,11 @@ function print_edit_product_form($product_id) {
 
 	/* set values for the form */
 	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
+	$frm["submit_caption"] = "Save_Changes";
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree(&$category_options, $frm["categories"]);
-
-	include("templates/product_form.ihtml");
+	build_category_tree($category_options, $frm["categories"]);
+	load_product_form_template($frm, $category_options, $errors);
 }
 
 function print_details_product($product_id) {
@@ -340,7 +428,7 @@ function print_details_product($product_id) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $weightunity;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the product */
 	$qid = db_query("
@@ -365,9 +453,75 @@ function print_details_product($product_id) {
 	}
 
 	/* build the categories listbox options, preselect the selected item */
-	build_category_tree(&$category_options, $frm["categories"]);
+	build_category_tree($category_options, $frm["categories"]);
 
-	include("templates/product_details.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_details.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	if (!empty($SESSION["goback"]["query_string"]))
+		$t->set_var("MEargs", "?" . $SESSION["goback"]["query_string"]);
+	else
+		$t->set_var("MEargs", "");
+	$t->set_var(array(
+			"frm_name"			=> ov($frm[name]),
+			"product_id"			=> $product_id,
+			"frm_extended_description"	=> ovwbr($frm["extended_description"]),
+			"frm_price"			=> $frm["price"],
+			"frm_fprice"			=> formatted_price($frm["price"]),
+			"frm_special_level"		=> $frm["special_level"],
+	));
+	$t->set_block("page", "brand_used", "brand_used_blck");
+	$t->set_var("brand_used_blck", "");
+	$t->set_block("page", "iva_used", "iva_used_blck");
+	$t->set_var("iva_used_blck", "");
+	$t->set_block("page", "discount_block", "discount_block_blck");
+	$t->set_var("discount_block_blck", "");
+		$t->set_block("discount_block", "discqty_block", "discqty_block_blck");
+		$t->set_var("discqty_block_blck", "");
+	$t->set_block("page", "weight_used", "weight_used_blck");
+	$t->set_var("weight_used_blck", "");
+	$t->set_block("page", "special_flag", "special_flag_blck");
+	$t->set_var("special_flag_blck", "");
+	$t->set_block("page", "adminprodimage", "adminprodimage_blck");
+	$t->set_var("adminprodimage_blck", "");
+	if ($SESSION["brand_used"] && $frm["bname"] != "") {
+		$t->set_var("bname", ov($frm["bname"]));
+		$t->parse("brand_used_blck", "brand_used", true);
+	}
+	if ($SESSION["iva_used"]) {
+		$t->set_var("iva", $frm["iva"]);
+		$t->parse("iva_used_blck", "iva_used", true);
+	}
+	if ($frm["discount"] > 0) {
+		$t->set_var("discount", $frm["discount"]);
+		if ($frm["discqty"] > 1) {
+			$t->set_var("discqty", $frm["discqty"]);
+			$t->parse("discqty_block_blck", "discqty_block", true);
+		}
+		$t->parse("discount_block_blck", "discount_block", true);
+	}
+	if ($SESSION["weight_used"]) {
+		$t->set_var(array(
+				"weight"	=> $frm["weight"],
+				"fweight"	=> formatted_weight($frm["weight"])
+		));
+		$t->parse("weight_used_blck", "weight_used", true);
+	}
+	if ($SESSION["special_flag"])
+		$t->parse("special_flag_blck", "special_flag", true);
+	if (file_exists($CFG->productsdir.string_cleanup($product_id).".".$frm["imagetype"])) {
+		$t->set_var(array(
+				"imagefilename"	=> string_cleanup($product_id),
+				"imagetype"	=> $frm["imagetype"],
+				"imagewidth"	=> $prod->imagewidth,
+				"imageheight"	=> $prod->imageheight
+		));
+		$t->parse("adminprodimage_blck", "adminprodimage", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/product_details.ihtml");
 }
 
 function delete_product($product_id) {
@@ -378,7 +532,7 @@ function delete_product($product_id) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$qid = db_begin();
 
@@ -413,7 +567,20 @@ function delete_product($product_id) {
 
 	$qid = db_commit();
 
-	include("templates/product_deleted.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_deleted.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"prod_name"	=> ov($prod->name),
+			"backurl"	=> $backurl
+	));
+        $t->pparse("out", "page");
+//	include("templates/product_deleted.ihtml");
 }
 
 function insert_product($frm, $HTTP_POST_FILES) {
@@ -421,7 +588,7 @@ function insert_product($frm, $HTTP_POST_FILES) {
  * going to in the variable $frm */
 
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if ($HTTP_POST_FILES['userfile']['tmp_name'] == "none") {
 		$type = "";
@@ -522,7 +689,20 @@ function insert_product($frm, $HTTP_POST_FILES) {
 
 	$qid = db_commit();
 
-	include("templates/product_added.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_added.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"frm_product_id"	=> ov($frm[product_id]),
+			"backurl"		=> $backurl
+	));
+        $t->pparse("out", "page");
+//	include("templates/product_added.ihtml");
 }
 
 function update_product($frm, $HTTP_POST_FILES) {
@@ -531,7 +711,7 @@ function update_product($frm, $HTTP_POST_FILES) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$type = $frm["old_imagetype"];
 	$imagewidth = $frm["old_imagewidth"];
@@ -680,7 +860,20 @@ foreach($HTTP_POST_FILES['userfile'] as $k => $v) {
 
 	$qid = db_commit();
 
-	include("templates/product_updated.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	$t->set_var(array(
+			"frm_product_id"	=> ov($frm[product_id]),
+			"backurl"		=> $backurl
+	));
+        $t->pparse("out", "page");
+//	include("templates/product_updated.ihtml");
 }
 
 function print_product_list() {
@@ -691,7 +884,7 @@ function print_product_list() {
 	global $SESSION;
 	global $weightunity;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
@@ -733,25 +926,96 @@ function print_product_list() {
 		$first = 0;
 		$last = $SESSION["numr"] - 1;
 	}
-	include("templates/product_list.ihtml");
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/product_list.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+		$t->set_block("page", "pages_links_top", "pages_links_top_blck");
+	$t->set_var("pages_links_top_blck", "");
+	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
+	$t->set_var("pages_links_bottom_blck", "");
+	if ($num_pages > 1) {
+		require("pages_links.php");
+		$t->set_var("pages_links", $pages_links);
+		$t->parse("pages_links_top_blck", "pages_links_top", true);
+		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
+	}
+	$t->set_block("page", "weight_used_th", "weight_used_th_blck");
+	$t->set_var("weight_used_th_blck", "");
+	if($SESSION["weight_used"])
+		$t->parse("weight_used_th_blck", "weight_used_th", true);
+	$t->set_block("page", "product_row", "product_rows");
+	$t->set_var("product_rows", "");
+		$t->set_block("product_row", "adminprodimage", "adminprodimage_blck");
+		$t->set_block("product_row", "adminprodnoimage", "adminprodnoimage_blck");
+		$t->set_block("product_row", "iva_used", "iva_used_blck");
+		$t->set_block("product_row", "weight_used_td", "weight_used_td_blck");
+	for ($i=$first; $i<=$last; $i++) {
+		$t->set_var("adminprodimage_blck", "");
+		$t->set_var("adminprodnoimage_blck", "");
+		$t->set_var("iva_used_blck", "");
+		$t->set_var("weight_used_td_blck", "");
+		if (file_exists($CFG->productsdir.string_cleanup($SESSION["products"][$i]["product_id"]).".thumb.jpg")) {
+			$t->set_var(array(
+					"imagefilename"	=> string_cleanup($SESSION["products"][$i]["product_id"]),
+					"thumbwidth"	=> $SESSION["products"][$i]["thumbwidth"],
+					"thumbheight"	=> $SESSION["products"][$i]["thumbheight"]
+			));
+			$t->parse("adminprodimage_blck", "adminprodimage", true);
+		} else
+			$t->parse("adminprodnoimage_blck", "adminprodnoimage", true);
+		$t->set_var(array(
+				"session_product_id"		=> ov($SESSION["products"][$i]["product_id"]),
+				"session_products_name"		=> ov($SESSION["products"][$i]["name"]),
+				"session_products_category"	=> ov($SESSION["products"][$i]["category"]),
+				"session_products_price"	=> $SESSION["products"][$i]["price"],
+				"session_products_fprice"	=> formatted_price($SESSION["products"][$i]["price"])
+		));
+		if ($SESSION["iva_used"]) {
+			$t->set_var("session_products_iva", $SESSION["products"][$i]["iva"]);
+			$t->parse("iva_used_blck", "iva_used", true);
+		}
+		if($SESSION["weight_used"]) {
+			$t->set_var(array(
+					"session_products_weight"	=> $SESSION["products"][$i]["weight"],
+					"session_products_fweight"	=> formatted_weight($SESSION["products"][$i]["weight"])
+			));
+			$t->parse("weight_used_td_blck", "weight_used_td", true);
+		}
+		$t->parse("product_rows", "product_row", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/product_list.ihtml");
 }
 
 function print_import_products_form() {
 /* print the import products form so we can add/update products from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Button_Label;
+	$frm["submit_caption"] = "Import_Button_Label";
 	$frm["newmode"] = "update_imp";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_products($HTTP_POST_FILES) {
 /* Import products from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* Let's open a transaction */
 	$qid = db_begin();
@@ -822,7 +1086,7 @@ function import_products($HTTP_POST_FILES) {
 
 			/* ... and let's see if the product already exists ... */
 			$qid = db_query("
-			SELECT id FROM products WHERE id = '$fldarr[1]'
+			SELECT id, name FROM products WHERE id = '$fldarr[1]'
 			");
 			if (db_num_rows($qid) == 0) {
 				/* ... if it doesn't exist let's create it in the products table ... */
@@ -903,26 +1167,47 @@ function import_products($HTTP_POST_FILES) {
 	$qid = db_commit();
 	
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
 function print_import_images_form() {
 /* print the import images form so we can add/update images from a zip file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Images_Button_Label . " (.tar.gz, .tgz, .zip)";
+	$frm["submit_caption"] = "Import_Images_Button_Label";
 	$frm["newmode"] = "update_impimg";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"]) . " (.tar.gz, .tgz, .zip)"
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_images($HTTP_POST_FILES) {
 /* Import products from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 	$upload_path = $CFG->productsdir;
 
 	/* Let's open a transaction */
@@ -966,7 +1251,7 @@ function import_images($HTTP_POST_FILES) {
 			}
 			if ($type != "") {
 				$upload_name_thumb = $upload_name.".thumb.jpg";
-				$upload_name_old = $upload_name;
+				$upload_name_old = $upload_name.".".$oldtype;
 				$upload_name .= ".".$type;
 				if (!copy($tmpdir.$file, $upload_name)) {
 					echo "<div class=normal>" . $image_upload_failed . "</div>";
@@ -983,7 +1268,7 @@ function import_images($HTTP_POST_FILES) {
 					$arr = db_fetch_array($qid, 0);
 					$oldtype = $arr["imagetype"];
 					if ($type != $oldtype) {
-						system ("rm -f ".$upload_name_old.".".$oldtype, $result);
+						system ("rm -f ".$upload_name_old, $result);
 					}
 
 					$qid = db_query("
@@ -1008,7 +1293,18 @@ function import_images($HTTP_POST_FILES) {
 	$qid = db_commit();
 	
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
