@@ -25,8 +25,8 @@ require_priv("admin");
 
 if (!isset($usertype)) { $usertype = "pf"; }
 
-$DOC_TITLE = $Users_Admin;
-include("templates/header.ihtml");
+$DOC_TITLE = "Users_Management";
+include("header.php");
 
 switch (nvl($mode)) {
 	case "details" :
@@ -106,9 +106,9 @@ switch (nvl($mode)) {
 			$frm["notes"] = $HTTP_POST_VARS["notes"];
 			$frm["ournotes"] = $HTTP_POST_VARS["ournotes"];
 			$frm["newmode"] = "insert";
-			$frm["submit_caption"] = $Add_User;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/user_form-".$HTTP_POST_VARS["usertype"].".ihtml");
+			$frm["submit_caption"] = "Add_User";
+			include("$CFG->dirroot"."/form_header.php");
+			load_user_form_template($frm, $HTTP_POST_VARS["usertype"], $page_number, $errors);
 		}
 		break;
 
@@ -169,16 +169,20 @@ switch (nvl($mode)) {
 			$frm["notes"] = $HTTP_POST_VARS["notes"];
 			$frm["ournotes"] = $HTTP_POST_VARS["ournotes"];
 			$frm["newmode"] = "update";
-			$frm["submit_caption"] = $Save_Changes;
-			include("$CFG->templatedir"."form_header.ihtml");
-			include("templates/user_form-".$HTTP_POST_VARS["usertype"].".ihtml");
+			$frm["submit_caption"] = "Save_Changes";
+			include("$CFG->dirroot"."/form_header.php");
+			load_user_form_template($frm, $HTTP_POST_VARS["usertype"], $page_number, $errors);
 		}
 		break;
 
 	case "resetpw" :
 		$return = reset_user_password($username);
 		if ($return == 0) {
-			include("templates/".$SESSION["lang"]."/user_password_reset.ihtml");
+			$t = new Template();
+			$t->set_file(array("page" => "templates/".$SESSION["lang"]."/user_password_reset.ihtml"));
+			$t->set_var("username", ov($username));
+			$t->pparse("out", "page");
+//			include("templates/".$SESSION["lang"]."/user_password_reset.ihtml");
 		} else {
 			include("templates/".$SESSION["lang"]."/password_not_reset.ihtml");
 		}
@@ -203,24 +207,113 @@ switch (nvl($mode)) {
 		break;
 }
 
-include("templates/footer.ihtml");
+include("footer.php");
 
 /******************************************************************************
  * FUNCTIONS
  *****************************************************************************/
 
+function load_user_form_template($frm, $usertype, $page_number, $errors) {
+
+	global $CFG, $ME;
+	global $SESSION;
+//	include ($CFG->globalerror);
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/user_form-".$usertype.".ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"page_number"		=> $page_number,
+			"frm_newmode"		=> $frm["newmode"],
+			"frm_old_email"		=> $frm["old_email"],
+			"frm_username"		=> ov($frm["username"]),
+			"errors_username"	=> errmsg($errors->username),
+			"frm_priv"		=> ov($frm["priv"]),
+			"errors_priv"		=> errmsg($errors->priv),
+			"frm_firstname"		=> ov($frm["firstname"]),
+			"errors_firstname"	=> errmsg($errors->firstname),
+			"frm_lastname"		=> ov($frm["lastname"]),
+			"errors_lastname"	=> errmsg($errors->lastname),
+			"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
+			"errors_fiscalcode"	=> errmsg($errors->fiscalcode),
+			"frm_address"		=> ov($frm["address"]),
+			"errors_address"	=> errmsg($errors->address),
+			"frm_number"		=> ov($frm["number"]),
+			"errors_number"		=> errmsg($errors->number),
+			"frm_city"		=> ov($frm["city"]),
+			"errors_city"		=> errmsg($errors->city),
+			"frm_country"		=> ov($frm["country"]),
+			"errors_country"	=> errmsg($errors->country),
+			"frm_zip_code"		=> ov($frm["zip_code"]),
+			"errors_zip_code"	=> errmsg($errors->zip_code),
+			"frm_phone"		=> ov($frm["phone"]),
+			"errors_phone"		=> errmsg($errors->phone),
+			"frm_fax"		=> ov($frm["fax"]),
+			"errors_fax"		=> errmsg($errors->fax),
+			"frm_mobilephone"	=> ov($frm["mobilephone"]),
+			"errors_mobilephone"	=> errmsg($errors->mobilephone),
+			"frm_email"		=> ov($frm["email"]),
+			"errors_email"		=> errmsg($errors->email),
+			"frm_authdata"		=> $frm["authdata"] ? "checked" : "" ,
+			"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "" ,
+			"frm_notes"		=> ov($frm["notes"]),
+			"errors_notes"		=> errmsg($errors->notes),
+			"frm_ournotes"		=> ov($frm["ournotes"]),
+			"errors_ournotes"	=> errmsg($errors->ournotes),
+			"frm_description"	=> ov($frm["description"]),
+			"errors_description"	=> errmsg($errors->brand_description),
+			"frm_submit_caption"	=> $t->get_var($frm["submit_caption"])
+	));
+	$t->set_block("page", "username_notok", "username_notok_blck");
+	$t->set_var("username_notok_blck", "");
+	$t->set_block("page", "username_ok", "username_ok_blck");
+	$t->set_var("username_ok_blck", "");
+	if ($frm["username"] == "" || $errors->username)
+		$t->parse("username_notok_blck", "username_notok", true);
+	else
+		$t->parse("username_ok_blck", "username_ok", true);
+	$t->pparse("out", "page");
+//	include("templates/user_form-".$HTTP_POST_VARS["usertype"].".ihtml");
+}
+
 function show_user_details($username) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
-	$qid = db_query("
-	SELECT * FROM users WHERE username = '$username'
-	");
+	$qid = db_query("SELECT * FROM users WHERE username = '$username'");
 	$frm = db_fetch_array($qid, 0);
 
-	include("templates/user_details-".$frm["usertype"].".ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/user_details-".$frm["usertype"].".ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_username"		=> ov($frm[username]),
+			"frm_priv"		=> ov($frm[priv]),
+			"frm_firstname"		=> ov($frm[firstname]),
+			"frm_lastname"		=> ov($frm[lastname]),
+			"frm_fiscalcode"	=> ov($frm[fiscalcode]),
+			"frm_address"		=> ovwbr($frm[address]),
+			"frm_number"		=> ov($frm[number]),
+			"frm_city"		=> ov($frm[city]),
+			"frm_country"		=> ov($frm[country]),
+			"frm_zip_code"		=> ov($frm[zip_code]),
+			"frm_phone"		=> ov($frm[phone]),
+			"frm_fax"		=> ov($frm[fax]),
+			"frm_mobilephone"	=> ov($frm[mobilephone]),
+			"frm_email"		=> ov($frm[email]),
+			"frm_authdata"		=> $frm["authdata"] ? strtoupper($yes) : "" ,
+			"frm_acceptadvert"	=> $frm["acceptadvert"] ? strtoupper($yes) : "" ,
+			"frm_notes"		=> ovwbr($frm[notes]),
+			"frm_ournotes"		=> ovwbr($frm[ournotes]),
+			"frm_date"		=> ov($frm[date]),
+	));
+	$t->pparse("out", "page");
+//	include("templates/user_details-".$frm["usertype"].".ihtml");
 }
 
 function print_add_user_form($usertype) {
@@ -229,7 +322,7 @@ function print_add_user_form($usertype) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set default values for the reset of the fields */
 	$frm["username"] = "";
@@ -249,9 +342,9 @@ function print_add_user_form($usertype) {
 	$frm["notes"] = "";
 
 	$frm["newmode"] = "insert";
-	$frm["submit_caption"] = $Add_User;
+	$frm["submit_caption"] = "Add_User";
 
-	include("templates/user_form-".$usertype.".ihtml");
+	load_user_form_template($frm, $usertype, $page_number, $errors);
 }
 
 function print_edit_user_form($username) {
@@ -260,7 +353,7 @@ function print_edit_user_form($username) {
 	global $CFG, $ME;
 	global $SESSION;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* load up the information for the user */
 	$qid = db_query("
@@ -270,9 +363,9 @@ function print_edit_user_form($username) {
 	$frm["old_email"] = $frm["email"];
 
 	$frm["newmode"] = "update";
-	$frm["submit_caption"] = $Save_Changes;
+	$frm["submit_caption"] = "Save_Changes";
 
-	include("templates/user_form-".$frm["usertype"].".ihtml");
+	load_user_form_template($frm, $frm["usertype"], $page_number, $errors);
 }
 
 function delete_user($username) {
@@ -280,13 +373,22 @@ function delete_user($username) {
 
 	global $CFG, $ME;
 	global $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$qid = db_query("SELECT priv FROM users WHERE username = '$username'");
 	$user = db_fetch_object($qid, 0);
 	if ($user->priv != "admin") {
 		$qid = db_query("DELETE FROM users WHERE username = '$username'");
-		include("templates/user_deleted.ihtml");
+
+		$t = new Template();
+		$t->set_file(array("page" => "templates/user_deleted.ihtml"));
+		require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		$t->set_var(array(
+				"username"	=> ov($username),
+		));
+		$t->pparse("out", "page");
+//		include("templates/user_deleted.ihtml");
 	} else {
 		include("templates/".$SESSION["lang"]."/admin_not_deleted.ihtml");
 	}
@@ -299,7 +401,7 @@ function insert_user($frm) {
 
 	global $CFG, $SESSION;
 	global $myday, $mymonth;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
 	$fromip = getenv("REMOTE_ADDR");
@@ -356,7 +458,15 @@ function insert_user($frm) {
 		,'$fromip'
 	)");
 
-	include("templates/user_added.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/user_added.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"frm_username"	=> ov($frm[username]),
+	));
+	$t->pparse("out", "page");
+//	include("templates/user_added.ihtml");
 }
 
 function update_user($frm) {
@@ -364,7 +474,7 @@ function update_user($frm) {
 
 	global $CFG, $SESSION;
 	global $username;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$qid = db_query("
 	UPDATE users SET
@@ -387,7 +497,16 @@ function update_user($frm) {
 		,ournotes = '$frm[ournotes]'
 	WHERE username = '$frm[username]'
 	");
-	include("templates/user_updated.ihtml");
+
+	$t = new Template();
+	$t->set_file(array("page" => "templates/user_updated.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var(array(
+			"username"	=> ov($username),
+	));
+	$t->pparse("out", "page");
+//	include("templates/user_updated.ihtml");
 }
 
 function print_user_list() {
@@ -398,7 +517,7 @@ function print_user_list() {
 	global $SESSION;
 	global $yes;
 	global $page_number, $dbchanged;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
@@ -406,7 +525,7 @@ function print_user_list() {
 		FROM users
 		WHERE username <> 'root'
 		ORDER BY username ASC
-  		");
+		");
 
 		$SESSION["numr"] = db_num_rows($qid);
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
@@ -429,25 +548,66 @@ function print_user_list() {
 		$last = $SESSION["numr"] - 1;
 	}
 
-	include("templates/user_list.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/user_list.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_block("page", "pages_links_top", "pages_links_top_blck");
+	$t->set_var("pages_links_top_blck", "");
+	$t->set_block("page", "pages_links_bottom", "pages_links_bottom_blck");
+	$t->set_var("pages_links_bottom_blck", "");
+	if ($num_pages > 1) {
+		require("pages_links.php");
+		$t->set_var("pages_links", $pages_links);
+		$t->parse("pages_links_top_blck", "pages_links_top", true);
+		$t->parse("pages_links_bottom_blck", "pages_links_bottom", true);
+	}
+	$t->set_block("page", "user_row", "user_rows");
+	$t->set_var("user_rows", "");
+	for ($i=$first; $i<=$last; $i++) {
+		$t->set_var(array(
+				"page_number"		=> $page_number,
+				"session_username"	=> ov($SESSION["users"][$i]["username"]),
+				"session_firstname"	=> ov($SESSION["users"][$i]["firstname"]),
+				"session_lastname"	=> $SESSION["users"][$i]["lastname"] == "" ? "&nbsp;" : ov($SESSION["users"][$i]["lastname"]),
+				"session_phone"		=> ov($SESSION["users"][$i]["phone"]),
+				"session_email"		=> ov($SESSION["users"][$i]["email"]),
+				"session_authdata"	=> $SESSION["users"][$i]["authdata"] ? strtoupper($yes) : "&nbsp;",
+				"session_acceptadvert"	=> $SESSION["users"][$i]["acceptadvert"] ? strtoupper($yes) : "&nbsp;"
+		));
+		$t->parse("user_rows", "user_row", true);
+	}
+	$t->pparse("out", "page");
+//	include("templates/user_list.ihtml");
 }
 
 function print_import_users_form() {
 /* print the import users form so we can add/update users from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* set values for the form */
-	$frm["submit_caption"] = $Import_Button_Label;
+	$frm["submit_caption"] = "Import_Button_Label";
 	$frm["newmode"] = "update_imp";
 
-	include("templates/data_import.ihtml");
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_form.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var(array(
+			"frm_newmode"			=> $frm["newmode"],
+			"session_max_file_size_import"	=> $SESSION["max_file_size_import"],
+			"frm_submit_caption"		=> $t->get_var($frm["submit_caption"])
+	));
+	$t->pparse("out", "page");
+//	include("templates/data_import_form.ihtml");
 }
 
 function import_users($userfile) {
 /* Import users from a text file */
 	global $CFG, $ME, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	/* Let's open a transaction */
 	$qid = db_begin();
@@ -553,7 +713,18 @@ function import_users($userfile) {
 	$qid = db_commit();
 	
 	/* The End */
-	include("templates/data_import_end.ihtml");
+	if (empty($SESSION["goback"]["query_string"]))
+		$backurl = $SESSION["goback"]["request_uri"] . "?dbchanged=1";
+	else
+		$backurl = $SESSION["goback"]["request_uri"] . "&dbchanged=1";
+	$t = new Template();
+	$t->set_file(array("page" => "templates/data_import_end.ihtml"));
+	require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+	require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+	$t->set_var("ME", $ME);
+	$t->set_var("backurl", $backurl);
+	$t->pparse("out", "page");
+//	include("templates/data_import_end.ihtml");
 
 }
 
