@@ -24,24 +24,29 @@ class object {};
 $CFG = new object;
 
 $CFG->dbhost = "localhost";
-$CFG->port = "5432";
+$CFG->dbms = "pgsql";	// PostgreSQL
+$CFG->port = "5432";	// PostgreSQL
+//$CFG->dbms = "mysql";	// MySQL
+//$CFG->port = "3306";	// MySQL
 $CFG->dbname = "pgmarket";
-$CFG->dbuser = "postgres";
-$CFG->dbpass = "postgres";
+$CFG->dbuser = "postgres";	// PostgreSQL
+$CFG->dbpass = "postgres";	// PostgreSQL
+//$CFG->dbuser = "mysql";	// MySQL
+//$CFG->dbpass = "mysql";	// MySQL
 
-$CFG->myname = "PgMarket 1.4.4";
+$CFG->myname = "PgMarket 1.5.0 (development)";
 
 $CFG->wwwroot     = "/~pratesi/pgmarket";	// without an ending "/"
-$CFG->firstpage   = "$CFG->wwwroot/firstpage.php";
 $CFG->dirroot     = "/home/pratesi/public_html/pgmarket";	// without an ending "/"
-$CFG->templatedir = "$CFG->dirroot/templates/";	// with an ending "/"
-$CFG->libdir      = "$CFG->dirroot/lib";	// without an ending "/"
-$CFG->libwww      = "$CFG->wwwroot/lib";	// without an ending "/"
-$CFG->localedir   = "$CFG->dirroot/locale/";	// with an ending "/"
-$CFG->productswww = "$CFG->wwwroot/products/";	// with an ending "/"
-$CFG->productsdir = "$CFG->dirroot/products/";	// with an ending "/"
-$CFG->images      = "$CFG->wwwroot/images/";	// with an ending "/"
-$CFG->wordlist    = "$CFG->libdir/wordlist.txt";
+$CFG->firstpage   = $CFG->wwwroot . "/firstpage.php";
+$CFG->templatedir = $CFG->dirroot . "/templates/";	// with an ending "/"
+$CFG->libdir      = $CFG->dirroot . "/lib";	// without an ending "/"
+$CFG->libwww      = $CFG->wwwroot . "/lib";	// without an ending "/"
+$CFG->localedir   = $CFG->dirroot . "/locale/";	// with an ending "/"
+$CFG->productswww = $CFG->wwwroot . "/products/";	// with an ending "/"
+$CFG->productsdir = $CFG->dirroot . "/products/";	// with an ending "/"
+$CFG->images      = $CFG->wwwroot . "/images/";	// with an ending "/"
+$CFG->wordlist    = $CFG->libdir . "/wordlist.txt";
 
 $CFG->pnmpath     = "/usr/bin";	// without an ending "/"
 
@@ -58,10 +63,11 @@ $DB_DEBUG = true;
 $DB_DIE_ON_FAIL = true;
 
 /* load up standard libraries */
-require("$CFG->libdir/stdlib.inc.php");
-require("$CFG->libdir/dblib.inc.php");
-require("$CFG->libdir/pgmarket.inc.php");
-require("$CFG->libdir/cart.inc.php");
+require($CFG->libdir . "/stdlib.inc.php");
+require($CFG->libdir . "/" . $CFG->dbms . ".inc.php");
+require($CFG->libdir . "/pgmarket.inc.php");
+require($CFG->libdir . "/cart.inc.php");
+require($CFG->libdir . "/template.inc.php");
 
 /* setup some global variables */
 $ME = qualified_me();
@@ -109,9 +115,9 @@ if (! isset($SESSION["lang"])) {
 //	$SESSION["lang"] = "it";
 	$SESSION["lang"] = "us";
 }
-$CFG->global = $CFG->localedir.$SESSION["lang"]."/global.inc.php";
+$CFG->globalerror = $CFG->localedir.$SESSION["lang"]."/global-error.inc.php";
 
-include ($CFG->global);
+//include ($CFG->global);
 
 //$currency = "Lit";
 $currency = "$";
@@ -192,29 +198,29 @@ $SESSION["brands_per_page"] = 10;	// max number of brands to be shown per page (
 $SESSION["iva_per_page"] = 10;		// max number of iva percentages to be shown per page (admin iva page)
 $SESSION["orders_states_per_page"] = 10; // max number of orders states to be shown per page (admin orders state page)
 
-$ordersdb[Customer]	= "Customer      :";
-$ordersdb[Phone]	= "Phone Contact :";
-$ordersdb[Address]	= "Address       :";
-$ordersdb[Cash_On_Delivery] = "Cash on Delivery";
-$ordersdb[Order] = "Order";
-$ordersdb[Username] = "Username";
-$ordersdb[Date] = "Date";
-$ordersdb[Comments] = "Comments";
-$ordersdb[TOTAL] = "TOTAL";
-$ordersdb[Product] = "Product";
-$ordersdb[Unit_Price] = "Unit price";
-$ordersdb[Number_of_items] = "Number of items";
-$ordersdb[Delivery] = "Delivery";
+$ordersdb["Customer"]	= "Customer      :";
+$ordersdb["Phone"]	= "Phone Contact :";
+$ordersdb["Address"]	= "Address       :";
+$ordersdb["Cash_On_Delivery"] = "Cash on Delivery";
+$ordersdb["Order"] = "Order";
+$ordersdb["Username"] = "Username";
+$ordersdb["Date"] = "Date";
+$ordersdb["Comments"] = "Comments";
+$ordersdb["TOTAL"] = "TOTAL";
+$ordersdb["Product"] = "Product";
+$ordersdb["Unit_Price"] = "Unit price";
+$ordersdb["Number_of_items"] = "Number of items";
+$ordersdb["Delivery"] = "Delivery";
 
-$contact[NameOrCompanyName] = "Name (Company Name): ";
-$contact[Address] = "Address:";
-$contact[Phone]         = "Phone:        ";
-$contact[Fax]           = "Fax:          ";
-$contact[MobilePhone]   = "Mobile Phone: ";
-$contact[EMail]         = "E-Mail:       ";
-$contact[AuthData]      = "Authorization for data handling: ";
-$contact[AuthAdvert]    = "Acceptance of advertising material: ";
-$contact[Message]       = "Message:";
+$contact["NameOrCompanyName"]	= "Name (Company Name): ";
+$contact["Address"] = "Address:";
+$contact["Phone"]		= "Phone:        ";
+$contact["Fax"]			= "Fax:          ";
+$contact["MobilePhone"]		= "Mobile Phone: ";
+$contact["EMail"]		= "E-Mail:       ";
+$contact["AuthData"]		= "Authorization for data handling: ";
+$contact["AuthAdvert"]		= "Acceptance of advertising material: ";
+$contact["Message"]		= "Message:";
 
 $myday[1] = "Monday";
 $myday[2] = "Tuesday";
