@@ -59,10 +59,14 @@ function require_priv($priv) {
  * it will display an Insufficient Privileges page and stop */
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
 
 	if ($SESSION["user"]["priv"] != $priv) {
-		include("$CFG->templatedir"."insufficient_privileges.ihtml");
+		$t = new Template();
+		$t->set_file(array("page" => "$CFG->templatedir"."insufficient_privileges.ihtml"));
+		require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+		$t->set_var("wwwroot", $CFG->wwwroot);
+		$t->pparse("out", "page");
+//		include("$CFG->templatedir"."insufficient_privileges.ihtml");
 		die;
 	}
 }
@@ -90,12 +94,12 @@ function build_category_tree(&$output, &$preselected, $parent=1, $indent="") {
 		$selected = in_array($cat->id, $preselected) ? "selected" : "";
 		$output .= "<option value=\"" . ov($cat->id) . "\" $selected>" . $indent . ov($cat->name);
 		if ($cat->id != $parent) {
-			build_category_tree(&$output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
+			build_category_tree($output, $preselected, $cat->id, $indent."&nbsp;&nbsp;");
 		}
 	}
 }
 
-function build_catbrowser(&$output, $parent=1, $indent=".") {
+function build_catbrowser(&$output, $parent=1, $indent="..") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
@@ -115,7 +119,7 @@ function build_catbrowser(&$output, $parent=1, $indent=".") {
 	}
 }
 
-function build_catbrowser_js(&$output, $parent=1, $indent=".") {
+function build_catbrowser_js(&$output, $parent=1, $indent="..") {
 /* recursively go through the category tree, starting at a parent, and
  * drill down, printing options for a selection list box.
  * this is not an efficient algorithm because it has to issue
@@ -155,20 +159,16 @@ function generate_password($maxlen=10) {
 	return substr($word1 . $filler1 . $word2, 0, $maxlen);
 }
 
-function err(&$errorvar) {
-/* if $errorvar is set, then print an error marker << */
-
-	if (isset($errorvar)) {
-		echo "<font color=#ff0000>&lt;&lt;</font>";
-	}
+function errmsg(&$errorvar) {
+/* if $errorvar is set, then returns an error marker << */
+	if (isset($errorvar))
+		return "<font color=#ff0000>&lt;&lt;</font>";
 }
 
-function err2(&$errorvar) {
-/* like err(), but prints the marker >> */
-
-	if (isset($errorvar)) {
-		echo "<font color=#ff0000>&gt;&gt;</font>";
-	}
+function errmsg2(&$errorvar) {
+/* like errmsg(), but returns the marker >> */
+	if (isset($errorvar))
+		return "<font color=#ff0000>&gt;&gt;</font>";
 }
 
 function username_exists($username) {
@@ -222,9 +222,9 @@ function reset_user_password($username) {
 	return 0;
 }
 
-function get_category_tree($id=1) {
-/* returns a tree of the product categories, starting from the top to the
- * category specified by $id */
+function build_category_path($id=1, &$category_path) {
+// puts recursively in $category_path the path of the product categories,
+// starting from the top to the category specified by $id
 
 	global $CFG;
 
@@ -238,20 +238,15 @@ function get_category_tree($id=1) {
 	}
 
 	if ($parent > 1) {
-		return print_category_tree($parent) . " &gt; " . $name;
+		$category_path = " &gt; " . $name . $category_path;
+		build_category_path($parent, &$category_path);
 	} elseif ($id > 1) {
-		return "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name;
+		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a> &gt; " . $name . $category_path;
 	} elseif ($id == 1) {
-		return "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>";
+		$category_path = "<a href='$CFG->wwwroot/shopping/?id=1'>Top</a>" . $category_path;
 	}
 }
 
-function print_category_tree($id=false) {
-/* prints the category tree by calling get_category_tree */
-
-	echo get_category_tree($id);
-}
-
 function get_cart_items() {
 /* return a $qid of all the items in the shopping cart */
 
@@ -351,7 +346,7 @@ function get_iva($iva_id) {
 function validate_username($username, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_username = str_replace(" ", "", $username);
 
@@ -376,7 +371,7 @@ function validate_username($username, &$errors, &$msg) {
 function validate_password($password, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_password = str_replace(" ", "", $password);
 	eregi ("[a-z0-9]{32}", $password, $matched_password);
@@ -397,7 +392,7 @@ function validate_password($password, &$errors, &$msg) {
 function validate_firstname($firstname, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($firstname)) {
 		$errors->firstname = true;
@@ -411,7 +406,7 @@ function validate_firstname($firstname, &$errors, &$msg) {
 function validate_ragionesociale($ragionesociale, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($ragionesociale)) {
 		$errors->firstname = true;
@@ -425,7 +420,7 @@ function validate_ragionesociale($ragionesociale, &$errors, &$msg) {
 function validate_name($name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($name)) {
 		$errors->name = true;
@@ -439,7 +434,7 @@ function validate_name($name, &$errors, &$msg) {
 function validate_lastname($lastname, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($lastname)) {
 		$errors->lastname = true;
@@ -453,7 +448,7 @@ function validate_lastname($lastname, &$errors, &$msg) {
 function validate_customer($customer, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($customer)) {
 		$errors->customer = true;
@@ -467,7 +462,7 @@ function validate_customer($customer, &$errors, &$msg) {
 function validate_fiscalcode($fiscalcode, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$even["0"] = 1;
 	$even["1"] = 0;
@@ -576,7 +571,7 @@ function validate_fiscalcode($fiscalcode, &$errors, &$msg) {
 function validate_partitaiva($partitaiva, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($partitaiva)) {
 		$errors->fiscalcode = true;
@@ -596,7 +591,7 @@ function validate_partitaiva($partitaiva, &$errors, &$msg) {
 function validate_address($address, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($address)) {
 		$errors->address = true;
@@ -610,7 +605,7 @@ function validate_address($address, &$errors, &$msg) {
 function validate_number($number, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($number) > $SESSION["number_length"]) {
 		$errors->number = true;
@@ -621,7 +616,7 @@ function validate_number($number, &$errors, &$msg) {
 function validate_city($city, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($city)) {
 		$errors->city = true;
@@ -635,7 +630,7 @@ function validate_city($city, &$errors, &$msg) {
 function validate_country($country, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($country)) {
 		$errors->country = true;
@@ -649,7 +644,7 @@ function validate_country($country, &$errors, &$msg) {
 function validate_zip_code($zip_code, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if ($zip_code == "") {
 		$errors->zip_code = true;
@@ -669,7 +664,7 @@ function validate_zip_code($zip_code, &$errors, &$msg) {
 function validate_phone($phone, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($phone)) {
 		$errors->phone = true;
@@ -698,7 +693,7 @@ function validate_phone($phone, &$errors, &$msg) {
 function validate_contact($contact, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($contact)) {
 		$errors->contact = true;
@@ -727,7 +722,7 @@ function validate_contact($contact, &$errors, &$msg) {
 function validate_fax($fax, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($fax) > $SESSION["fax_length"]) {
 		$errors->fax = true;
@@ -753,7 +748,7 @@ function validate_fax($fax, &$errors, &$msg) {
 function validate_mobilephone($mobilephone, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($mobilephone) > $SESSION["mobilephone_length"]) {
 		$errors->mobilephone = true;
@@ -779,7 +774,7 @@ function validate_mobilephone($mobilephone, &$errors, &$msg) {
 function validate_email($email, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($email)) {
 		$errors->email = true;
@@ -799,7 +794,7 @@ function validate_email($email, &$errors, &$msg) {
 function validate_notes($notes, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($notes) > $SESSION["notes_length"]) {
 		$errors->notes = true;
@@ -810,7 +805,7 @@ function validate_notes($notes, &$errors, &$msg) {
 function validate_message($message, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($message)) {
 		$errors->message = true;
@@ -824,7 +819,7 @@ function validate_message($message, &$errors, &$msg) {
 function validate_ournotes($ournotes, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($ournotes) > $SESSION["ournotes_length"]) {
 		$errors->ournotes = true;
@@ -835,7 +830,7 @@ function validate_ournotes($ournotes, &$errors, &$msg) {
 function validate_comments($comments, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($comments) > $SESSION["comments_length"]) {
 		$errors->comments = true;
@@ -846,7 +841,7 @@ function validate_comments($comments, &$errors, &$msg) {
 function validate_category_name($category_name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_category_name = str_replace(" ", "", $category_name);
 
@@ -862,7 +857,7 @@ function validate_category_name($category_name, &$errors, &$msg) {
 function validate_category_description($category_description, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($category_description) > $SESSION["category_description_length"]) {
 		$errors->category_description = true;
@@ -873,7 +868,7 @@ function validate_category_description($category_description, &$errors, &$msg) {
 function validate_brand_name($brand_name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_brand_name = str_replace(" ", "", $brand_name);
 
@@ -889,7 +884,7 @@ function validate_brand_name($brand_name, &$errors, &$msg) {
 function validate_brand_description($brand_description, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($brand_description) > $SESSION["brand_description_length"]) {
 		$errors->brand_description = true;
@@ -900,7 +895,7 @@ function validate_brand_description($brand_description, &$errors, &$msg) {
 function validate_product_id($product_id, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (empty($product_id)) {
 		$errors->product_id = true;
@@ -928,7 +923,7 @@ function validate_product_id($product_id, &$errors, &$msg) {
 function product_id_exists($product_id, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$qid = db_query("
 	SELECT id FROM products WHERE id = '$product_id'
@@ -943,7 +938,7 @@ function product_id_exists($product_id, &$errors, &$msg) {
 function validate_product_name($product_name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_product_name = str_replace(" ", "", $product_name);
 
@@ -959,7 +954,7 @@ function validate_product_name($product_name, &$errors, &$msg) {
 function validate_price($price, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if ($price == "") {
 		$errors->price = true;
@@ -979,7 +974,7 @@ function validate_price($price, &$errors, &$msg) {
 function validate_iva($iva, &$errors, &$msg) {
 
 	global $CFG;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if ($iva != "") {
 		eregi ("[0-9]{0,}[.]{0,1}[0-9]{0,}", $iva, $matched_iva);
@@ -996,7 +991,7 @@ function validate_iva($iva, &$errors, &$msg) {
 function validate_discount($discount, $discqty, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if ($discount.$discqty != "") {
 		if (($discount != 0) && ($discount == "" || $discqty == "")) {
@@ -1030,7 +1025,7 @@ function validate_discount($discount, $discqty, &$errors, &$msg) {
 function validate_order_state_name($order_state_name, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$stripped_order_state_name = str_replace(" ", "", $order_state_name);
 
@@ -1046,7 +1041,7 @@ function validate_order_state_name($order_state_name, &$errors, &$msg) {
 function validate_order_state_description($order_state_description, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($order_state_description) > $SESSION["order_state_description_length"]) {
 		$errors->order_state_description = true;
@@ -1084,7 +1079,7 @@ function validate_weight($weight, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
 	global $weightunity;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if ($weight == "") {
 		$errors->weight = true;
@@ -1107,7 +1102,7 @@ function validate_weight($weight, &$errors, &$msg) {
 function validate_special_level($special_level, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 /*
 	if ($special_level == "") {
@@ -1124,7 +1119,7 @@ function validate_special_level($special_level, &$errors, &$msg) {
 function validate_product_description($product_description, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($product_description) > $SESSION["product_description_length"]) {
 		$errors->product_description = true;
@@ -1135,7 +1130,7 @@ function validate_product_description($product_description, &$errors, &$msg) {
 function validate_product_extended_description($product_extended_description, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($product_extended_description) > $SESSION["product_extended_description_length"]) {
 		$errors->product_extended_description = true;
@@ -1146,7 +1141,7 @@ function validate_product_extended_description($product_extended_description, &$
 function validate_priv($priv, &$errors, &$msg) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	if (strlen($priv) > $SESSION["priv_length"]) {
 		$errors->priv = true;
