@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -52,7 +52,17 @@ if (match_referer() && isset($HTTP_POST_VARS)) {
 	}
 } */
 
-include("$CFG->templatedir"."login_form.ihtml");
+$t = new Template();
+$t->set_file(array("page" => "$CFG->templatedir"."login_form.ihtml"));
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+$t->set_var(array(
+		"wwwroot"	=> $CFG->wwwroot,
+		"libwww"	=> $CFG->libwww,
+		"errormsg"	=> ov($errormsg),
+		"frm_username"	=> ov($frm["username"])
+));
+$t->pparse("out", "page");
+//include("$CFG->templatedir"."login_form.ihtml");
 
 /******************************************************************************
  * FUNCTIONS
