@@ -1,6 +1,7 @@
 <?
 
-/* (c) 2000 Fabio Molinari <fabio.m@mclink.it>
+/*
+ * (c) 2000 Fabio Molinari <fabio.m@mclink.it>
  * (c) 2000, 2001 Marco Pratesi <pratesi@telug.it>
  * (c) 2000 Oleg V. Kalashnikov <oleg@ok.gnu.zp.ua>
  * (c) 2000 Ying Zhang <ying@zippydesign.com>
@@ -13,11 +14,10 @@
 include("../application.inc.php");
 global $CFG, $ME;
 global $SESSION;
-global $weightunity;
-include ($CFG->global);
+//include ($CFG->globalerror);
 
-$DOC_TITLE = $AdvancedSearch;
-include("$CFG->templatedir"."header.ihtml");
+$DOC_TITLE = "AdvancedSearch";
+include("$CFG->dirroot"."/header.php");
 
 /* Form has been submitted, let's go searching. */
 
@@ -82,30 +82,84 @@ if (match_referer() && !isset($from_menu)) {
 			if (!($num_pages == (integer) $num_pages)) {
 				$num_pages = (integer) $num_pages + 1;
 			}
-			include("templates/search_results.ihtml");
+//			include("templates/search_results.ihtml");
 		} else {
 			$first = 0;
 			$last = $SESSION["numr"] - 1;
-			include("templates/search_results.ihtml");
+//			include("templates/search_results.ihtml");
 		}
-		include("$CFG->templatedir"."footer.ihtml");
+		require("search_results.php");
+		include("$CFG->dirroot"."/footer.php");
 		die;
 	}
 }
 
+$t = new Template();
+$t->set_file(array("page" => "templates/advanced_search_form.ihtml"));
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
+$t->set_var("wwwroot", $CFG->wwwroot);
+$t->set_var("productswww", $CFG->productswww);
+$t->set_var("ME", $ME);
+$t->set_var("id", $id);
+if (empty($errors))
+	$t->set_var("there_are_errors", "");
+$t->set_var(array(
+		"session_product_name_in"	=> ov($SESSION["product_name_in"]),
+		"session_prod_concatenation_or"	=> $SESSION["prod_concatenation"] == "AND" ? "" : "checked",
+		"session_prod_concatenation_and"=> $SESSION["prod_concatenation"] == "AND" ? "checked" : "",
+		"session_prod_case_sensitive"	=> $SESSION["prod_case_sensitive"] ? "checked" : "",
+		"session_name_in"		=> ov($SESSION["name_in"]),
+		"session_desc_concatenation_or"	=> $SESSION["desc_concatenation"] == "AND" ? "" : "checked",
+		"session_desc_concatenation_and"=> $SESSION["desc_concatenation"] == "AND" ? "checked" : "",
+		"session_desc_case_sensitive"	=> $SESSION["desc_case_sensitive"] ? "checked" : "",
+		"session_price_min"		=> ov($SESSION["price_min"]),
+		"errors_price_min"		=> errmsg($errors->price_min),
+		"session_price_max"		=> ov($SESSION["price_max"]),
+		"errors_price_max"		=> errmsg($errors->price_max),
+		"session_discount_min"		=> ov($SESSION["discount_min"]),
+		"errors_discount_min"		=> errmsg($errors->discount_min),
+		"session_discount_max"		=> ov($SESSION["discount_max"]),
+		"errors_discount_max"		=> errmsg($errors->discount_max),
+		"session_discqty_min"		=> ov($SESSION["discqty_min"]),
+		"errors_discqty_min"		=> errmsg($errors->discqty_min),
+		"session_discqty_max"		=> ov($SESSION["discqty_max"]),
+		"errors_discqty_max"		=> errmsg($errors->discqty_max)
+));
+$t->set_block("page", "brand_used", "brand_used_blck");
+$t->set_var("brand_used_blck", "");
 if ($SESSION["brand_used"]) {
+	$t->set_block("brand_used", "brand_row", "brand_rows");
+	$t->set_var("brand_rows", "");
 	$qid = db_query("SELECT id, name FROM brands");
 	$SESSION["brands"] = array();
 	$numr = db_num_rows($qid);
-	$SESSION["numbrands"] = $numr;
 	for ($i=0; $i<$numr; $i++) {
 		$brand = db_fetch_object($qid, $i);
-		$SESSION["brand"][$i]["id"] = $brand->id;
-		$SESSION["brand"][$i]["name"] = $brand->name;
+		$t->set_var(array(
+				"session_brand_id"	=> $brand->id,
+				"session_brand_selected"=> ($SESSION["brand_id"] == $SESSION["brand"][$i]["id"]) ? "selected" : "",
+				"session_brand_name"	=> $brand->name
+		));
+		$t->parse("brand_rows", "brand_row", true);
 	}
+	$t->parse("brand_used_blck", "brand_used", true);
 }
-include("templates/advanced_search_form.ihtml");
-include("$CFG->templatedir"."footer.ihtml");
+$t->set_block("page", "weight_used", "weight_used_blck");
+$t->set_var("weight_used_blck", "");
+if($SESSION["weight_used"]) {
+	$t->set_var(array(
+			"session_weight_min"	=> ov($SESSION["weight_min"]),
+			"errors_weight_min"	=> errmsg($errors->weight_min),
+			"session_weight_max"	=> ov($SESSION["weight_max"]),
+			"errors_weight_max"	=> errmsg($errors->weight_max)
+	));
+	$t->parse("weight_used_blck", "weight_used", true);
+}
+$t->pparse("out", "page");
+//include("templates/advanced_search_form.ihtml");
+
+include("$CFG->dirroot"."/footer.php");
 
 
 /******************************************************************************
@@ -117,11 +171,12 @@ function validate_form(&$frm, &$errors) {
  * the string is empty, then there are no errors */
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+//	include ($CFG->globalerror);
 
 	$errors = new Object;
 	$errormsg = "";
 
+/*
 	if(!empty($frm["product_name_min"])) {
 		validate_product_name($frm["product_name_min"], &$errors, &$errormsg);
 		if ($errors->product_name) $errors->product_name_min = true;
@@ -138,6 +193,7 @@ function validate_form(&$frm, &$errors) {
 		validate_product_description($frm["description_max"], &$errors, &$errormsg);
 		if ($errors->product_description) $errors->description_max = true;
 	}
+*/
 	if(!empty($frm["price_min"])) {
 		validate_price($frm["price_min"], &$errors, &$errormsg);
 		if ($errors->price) $errors->price_min = true;
@@ -146,16 +202,6 @@ function validate_form(&$frm, &$errors) {
 		validate_price($frm["price_max"], &$errors, &$errormsg);
 		if ($errors->price) $errors->price_max = true;
 	}
-//	if(!empty($frm["discount_min"]) || !empty($frm["discqty_min"])) {
-//		validate_discount($frm["discount_min"], $frm["discqty_min"], &$errors, &$errormsg);
-//		if ($errors->discount) $errors->discount_min = true;
-//		if ($errors->discqty) $errors->discqty_min = true;
-//	}
-//	if(!empty($frm["discount_max"]) || !empty($frm["discqty_max"])) {
-//		validate_discount($frm["discount_max"], $frm["discqty_max"], &$errors, &$errormsg);
-//		if ($errors->discount) $errors->discount_max = true;
-//		if ($errors->discqty) $errors->discqty_max = true;
-//	}
 	if(!empty($frm["discount_min"])) {
 		validate_searched_discount($frm["discount_min"], &$errors, &$errormsg);
 		if ($errors->discount) $errors->discount_min = true;
