@@ -43,7 +43,20 @@ a un opportuno template.
 
 */
 
-if ($paybutton == $Cash_On_Delivery) { // si tratta di un pagamento in contrassegno
+$t = new Template();
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+if ($paybutton == $t->get_var("Cash_On_Delivery")) // si tratta di un pagamento in contrassegno
+	$DOC_TITLE = "Order_Completed_Successfully";
+else if ($paybutton == $t->get_var("Credit_Card"))
+	$DOC_TITLE = "submission_to_banca_sella";
+include("$CFG->dirroot"."/header.php");
+
+$t = new Template();
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+require($CFG->localedir . $SESSION["lang"] . "/global-shopping.inc.php");
+require($CFG->localedir . $SESSION["lang"] . "/global-admin.inc.php");
+
+if ($paybutton == $t->get_var("Cash_On_Delivery")) { // si tratta di un pagamento in contrassegno
 
 	/* we will create the order in our database, then try to authorize the
  	* payment.  if all was successful, the user's order will have been
@@ -58,16 +71,20 @@ if ($paybutton == $Cash_On_Delivery) { // si tratta di un pagamento in contrasse
 		$emailbody,
 		"From: $CFG->support");
 
-	$DOC_TITLE = $Order_Completed_Successfully;
-	$template_to_show = "templates/".$SESSION["lang"]."/complete_order_success.ihtml";
-	$cart_total = $CART->grandtotal;
+	$t->set_file(array("page" => "templates/".$SESSION["lang"]."/complete_order_success.ihtml"));
+	$t->set_var(array(
+			"orderid"	=> $orderid,
+			"cart_total"	=> formatted_price($CART->grandtotal),
+			"firstpage"	=> $CFG->firstpage,
+			"myname"	=> $CFG->myname
+	));
 	/* clear out the shopping cart, so the user doesn't accidentally re-submit
  	* and purchase twice!! */
 	$CART->init();
 	clear_orderinfo();
 	$SESSION["wantsurl"] = "";
 
-} else if ($paybutton == $Credit_Card) {
+} else if ($paybutton == $t->get_var("Credit_Card")) {
 
 /////////////////////////////////////////////////////////////////////////
 // A PART OF THE CODE HAS BEEN CUT AWAY BECAUSE IT STRICTLY DEPENDS ON
@@ -76,14 +93,14 @@ if ($paybutton == $Cash_On_Delivery) { // si tratta di un pagamento in contrasse
 /////////////////////////////////////////////////////////////////////////
 
 	$orderid = create_order_cc($order, $passwordric);
-	$DOC_TITLE = $submission_to_banca_sella;
-	$template_to_show = "templates/".$SESSION["lang"]."/banca_sella_submit.ihtml";
+	$t->set_file(array("page" => "templates/".$SESSION["lang"]."/banca_sella_submit.ihtml"));
 
 }
 
-include("$CFG->templatedir"."header.ihtml");
-include($template_to_show);
-include("$CFG->templatedir"."footer.ihtml");
+$t->pparse("out", "page");
+//include($template_to_show);
+
+include("$CFG->dirroot"."/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
