@@ -2,6 +2,8 @@
 /* navigation.php (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 include("../application.inc.php");
+$t = new Template();
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
 ?>
 
 <html>
@@ -10,16 +12,17 @@ include("../application.inc.php");
 </head>
 <body class=nav topmargin="0" leftmargin="0" marginwidth="5" marginheight="10">
 
-<h1><?=$Categories_Browsing?></h1>
+<h1><?=$t->get_var("Categories_Browsing")?></h1>
 
 <table>
 <tr>
-<td class=label><a href="<?=$CFG->wwwroot?>/shopping/" target="bodyframe"><?=$Shopping?></a></td>
+<td class=label><?=$t->get_var("Categories")?>:</td>
 </tr>
 <tr valign=top>
 <td class=normal>
 <?
 build_catbrowser($categories);
+$categories = ".Top^" . $CFG->wwwroot . "/shopping/^" . $SESSION["catbrowser_target"] . "\n" . $categories;
 require("$CFG->libdir/treemenu.inc.php");
 ?>
 </td>
