@@ -28,15 +28,30 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 
 	if (empty($errormsg)) {
 		update_password($frm["newpassword"]);
-		$noticemsg = $Password_Change_Successful;
+		$noticemsg = "Password_Change_Successful";
 	}
 }
 
-$DOC_TITLE = $Change_Password;
-include("$CFG->templatedir"."header.ihtml");
-include("$CFG->templatedir"."form_header.ihtml");
-include("templates/change_password_form.ihtml");
-include("$CFG->templatedir"."footer.ihtml");
+$DOC_TITLE = "Change_Password";
+
+include("$CFG->dirroot"."/header.php");
+
+include("$CFG->dirroot"."/form_header.php");
+
+$t = new Template();
+$t->set_file(array("page" => "templates/change_password_form.ihtml"));
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+$t->set_var("ME", $ME);
+$t->set_var("md5dotjs", $CFG->libwww . "/md5.js");
+$t->set_var(array(
+		"errors_oldpassword"	=> errmsg($errors->oldpassword),
+		"errors_newpassword"	=> errmsg($errors->newpassword),
+		"errors_newpassword2"	=> errmsg($errors->newpassword2)
+));
+$t->pparse("out", "page");
+//include("templates/change_password_form.ihtml");
+
+include("$CFG->dirroot"."/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -45,7 +60,7 @@ include("$CFG->templatedir"."footer.ihtml");
 function validate_form(&$frm, &$errors) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$errors = new Object;
 	$msg = "";
