@@ -12,7 +12,7 @@
  * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
  */
 
-/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */
+/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
 
 /******************************************************************************
  * MAIN
@@ -28,17 +28,61 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 
 	if (empty($errormsg)) {
 		update_settings($frm);
-		$noticemsg = $Settings_Change_Successful;
+		$noticemsg = "Settings_Change_Successful";
 	}
 } else {
 	$frm = load_user_profile();
 }
 
-$DOC_TITLE = $Change_Settings;
-include("$CFG->templatedir"."header.ihtml");
-include("$CFG->templatedir"."form_header.ihtml");
-include("templates/change_settings_form-".$SESSION["user"]["usertype"].".ihtml");
-include("$CFG->templatedir"."footer.ihtml");
+$DOC_TITLE = "Change_Settings";
+
+include("$CFG->dirroot"."/header.php");
+
+include("$CFG->dirroot"."/form_header.php");
+
+$t = new Template();
+$t->set_file(array("page" => "templates/change_settings_form-".$SESSION["user"]["usertype"].".ihtml"));
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+$t->set_var("ME", $ME);
+$t->set_var(array(
+		"session_user_username"		=> ov($SESSION["user"]["username"]),
+		"session_user_firstname"	=> ov($SESSION["user"]["firstname"]),
+		"frm_fiscalcode"		=> ov($frm["fiscalcode"]),
+		"errors_fiscalcode"		=> errmsg($errors->fiscalcode),
+		"frm_address"			=> ov($frm["address"]),
+		"errors_address"		=> errmsg($errors->address),
+		"frm_number"			=> ov($frm["number"]),
+		"errors_number"			=> errmsg($errors->number),
+		"frm_city"			=> ov($frm["city"]),
+		"errors_city"			=> errmsg($errors->city),
+		"frm_country"			=> ov($frm["country"]),
+		"errors_country"		=> errmsg($errors->country),
+		"frm_zip_code"			=> ov($frm["zip_code"]),
+		"errors_zip_code"		=> errmsg($errors->zip_code),
+		"frm_phone"			=> ov($frm["phone"]),
+		"errors_phone"			=> errmsg($errors->phone),
+		"frm_fax"			=> ov($frm["fax"]),
+		"errors_fax"			=> errmsg($errors->fax),
+		"frm_mobilephone"		=> ov($frm["mobilephone"]),
+		"errors_mobilephone"		=> errmsg($errors->mobilephone),
+		"frm_email"			=> ov($frm["email"]),
+		"errors_email"			=> errmsg($errors->email),
+		"frm_authdata"			=> $frm["authdata"] ? "checked" : "",
+		"frm_acceptadvert"		=> $frm["acceptadvert"] ? "checked" : "",
+		"frm_notes"			=> ov($frm["notes"]),
+));
+if ($SESSION["user"]["usertype"] == "pf") {
+	$t->set_var("session_user_lastname", ov($SESSION["user"]["lastname"]));
+	if ($SESSION["country"] == "it") {
+		$t->set_block("page", "italy", "italy_blck");
+		$t->set_var("italy_blck", "");
+		$t->parse("italy_blck", "italy", true);
+	}
+}
+$t->pparse("out", "page");
+//include("templates/change_settings_form-".$SESSION["user"]["usertype"].".ihtml");
+
+include("$CFG->dirroot"."/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -47,7 +91,7 @@ include("$CFG->templatedir"."footer.ihtml");
 function validate_form(&$frm, &$errors) {
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$errors = new Object;
 	$msg = "";
@@ -60,7 +104,7 @@ function validate_form(&$frm, &$errors) {
 	validate_address($frm["address"], &$errors, &$msg);
 	validate_number($frm["number"], &$errors, &$msg);
 	validate_city($frm["city"], &$errors, &$msg);
-	validate_state($frm["state"], &$errors, &$msg);
+	validate_country($frm["country"], &$errors, &$msg);
 	validate_zip_code($frm["zip_code"], &$errors, &$msg);
 	validate_phone($frm["phone"], &$errors, &$msg);
 	validate_fax($frm["fax"], &$errors, &$msg);
@@ -90,7 +134,7 @@ function update_settings(&$frm) {
 		,address = '$frm[address]'
 		,number = '$frm[number]'
 		,city = '$frm[city]'
-		,state = '$frm[state]'
+		,country = '$frm[country]'
 		,zip_code = '$frm[zip_code]'
 		,phone = '$frm[phone]'
 		,fax = '$frm[fax]'
