@@ -29,25 +29,82 @@ if (match_referer() && isset($HTTP_POST_VARS) && !isset($from_menu)) {
 	if (empty($errormsg)) {
 		insert_user($frm, $usertype);
 
-		$DOC_TITLE = $Signup_Successful;
-		include("$CFG->templatedir"."header.ihtml");
-		include("templates/".$SESSION["lang"]."/signup_success.ihtml");
-		include("$CFG->templatedir"."footer.ihtml");
+		$DOC_TITLE = "Signup_Successful";
+		include("$CFG->dirroot"."/header.php");
+		$t = new Template();
+		$t->set_file(array("page" => "templates/".$SESSION["lang"]."/signup_success.ihtml"));
+		$t->set_var(array(
+				"frm_firstname"	=> ov($frm["firstname"]),
+				"frm_username"	=> ov($frm["username"]),
+				"frm_password"	=> ov($frm["password"]),
+				"wwwroot"	=> $CFG->wwwroot
+		));
+		$t->pparse("out", "page");
+//		include("templates/".$SESSION["lang"]."/signup_success.ihtml");
+		include("$CFG->dirroot"."/footer.php");
 		die;
 	}
-
-	if ($HTTP_POST_VARS["hiddencountry"] == "it")
-		$country = "it";
 }
 
-$DOC_TITLE = $Signup;
-include("$CFG->templatedir"."header.ihtml");
-include("$CFG->templatedir"."form_header.ihtml");
+$DOC_TITLE = "Signup";
+include("$CFG->dirroot"."/header.php");
+include("$CFG->dirroot"."/form_header.php");
+
 if (empty($errormsg)) {	// we are loading the form for the first time
 	$frm["acceptadvert"] = 1;
 }
-include("templates/signup_form-".$usertype.".ihtml");
-include("$CFG->templatedir"."footer.ihtml");
+
+$t = new Template();
+$t->set_file(array("page" => "templates/signup_form-".$usertype.".ihtml"));
+require($CFG->localedir . $SESSION["lang"] . "/global-common.inc.php");
+require($CFG->localedir . $SESSION["lang"] . "/global-users.inc.php");
+$t->set_var("ME", $ME);
+$t->set_var("md5dotjs", $CFG->libwww . "/md5.js");
+$t->set_var("star", return_star());
+$t->set_var(array(
+		"frm_username"		=> ov($frm["username"]),
+		"errors_username"	=> errmsg($errors->username),
+		"errors_password"	=> errmsg($errors->password),
+		"frm_firstname"		=> ov($frm["firstname"]),
+		"errors_firstname"	=> errmsg($errors->firstname),
+		"frm_lastname"		=> ov($frm["lastname"]),
+		"errors_lastname"	=> errmsg($errors->lastname),
+		"frm_address"		=> ov($frm["address"]),
+		"errors_address"	=> errmsg($errors->address),
+		"frm_number"		=> ov($frm["number"]),
+		"errors_number"		=> errmsg($errors->number),
+		"frm_city"		=> ov($frm["city"]),
+		"errors_city"		=> errmsg($errors->city),
+		"frm_country"		=> ov($frm["country"]),
+		"errors_country"	=> errmsg($errors->country),
+		"frm_zip_code"		=> ov($frm["zip_code"]),
+		"errors_zip_code"	=> errmsg($errors->zip_code),
+		"frm_phone"		=> ov($frm["phone"]),
+		"errors_phone"		=> errmsg($errors->phone),
+		"frm_fax"		=> ov($frm["fax"]),
+		"errors_fax"		=> errmsg($errors->fax),
+		"frm_mobilephone"	=> ov($frm["mobilephone"]),
+		"errors_mobilephone"	=> errmsg($errors->mobilephone),
+		"frm_email"		=> ov($frm["email"]),
+		"errors_email"		=> errmsg($errors->email),
+		"frm_authdata"		=> $frm["authdata"] ? "checked" : "",
+		"frm_acceptadvert"	=> $frm["acceptadvert"] ? "checked" : "",
+		"frm_notes"		=> ov($frm["notes"]),
+		"errors_notes"		=> errmsg($errors->notes),
+));
+$t->set_block("page", "fiscalcode", "fiscalcode_blck");
+$t->set_var("fiscalcode_blck", "");
+if ($country == "it" || $HTTP_POST_VARS["hiddencountry"] == "it" || $usertype == "az") {
+	$t->set_var(array(
+			"frm_fiscalcode"	=> ov($frm["fiscalcode"]),
+			"errors_fiscalcode"	=> errmsg($errors->fiscalcode)
+	));
+	$t->parse("fiscalcode_blck", "fiscalcode", true);
+}
+$t->pparse("out", "page");
+//include("templates/signup_form-".$usertype.".ihtml");
+
+include("$CFG->dirroot"."/footer.php");
 
 /******************************************************************************
  * FUNCTIONS
@@ -58,7 +115,7 @@ function validate_form(&$frm, &$errors, $usertype) {
  * the string is empty, then there are no errors */
 
 	global $CFG, $SESSION;
-	include ($CFG->global);
+	include ($CFG->globalerror);
 
 	$errors = new Object;
 	$msg = "";
@@ -83,7 +140,6 @@ function validate_form(&$frm, &$errors, $usertype) {
 	validate_address($frm["address"], &$errors, &$msg);
 	validate_number($frm["number"], &$errors, &$msg);
 	validate_city($frm["city"], &$errors, &$msg);
-	validate_country($frm["country"], &$errors, &$msg);
 	validate_zip_code($frm["zip_code"], &$errors, &$msg);
 	validate_phone($frm["phone"], &$errors, &$msg);
 	validate_fax($frm["fax"], &$errors, &$msg);
